"""empty message

Revision ID: 0cce33011766
Revises: 3f4e8bfd8a7f
Create Date: 2020-05-25 19:22:24.114156

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '0cce33011766'
down_revision = '3f4e8bfd8a7f'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('product_relations', schema=None) as batch_op:
        batch_op.alter_column('type_id',
               existing_type=sa.INTEGER(),
               nullable=False)

    with op.batch_alter_table('products', schema=None) as batch_op:
        batch_op.alter_column('type_id',
               existing_type=sa.INTEGER(),
               nullable=False)

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('products', schema=None) as batch_op:
        batch_op.alter_column('type_id',
               existing_type=sa.INTEGER(),
               nullable=True)

    with op.batch_alter_table('product_relations', schema=None) as batch_op:
        batch_op.alter_column('type_id',
               existing_type=sa.INTEGER(),
               nullable=True)

    # ### end Alembic commands ###
