"""add a column to product_types

Revision ID: d8afc036053a
Revises: d7cac99bbffa
Create Date: 2020-05-22 13:02:07.024023

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'd8afc036053a'
down_revision = 'd7cac99bbffa'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('product_types', sa.Column('order', sa.Integer(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('product_types', 'order')
    # ### end Alembic commands ###
