# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot


snapshots = Snapshot()

snapshots['test_disable_mutation[kwargs0] 1'] = {
    'data': {
        'Mutation': {
            'description': None,
            'fields': [
                {
                    'name': 'createProduct'
                },
                {
                    'name': 'updateProduct'
                },
                {
                    'name': 'deleteProduct'
                },
                {
                    'name': 'createProductFilePath'
                },
                {
                    'name': 'updateProductFilePath'
                },
                {
                    'name': 'deleteProductFilePath'
                },
                {
                    'name': 'createProductType'
                },
                {
                    'name': 'updateProductType'
                },
                {
                    'name': 'deleteProductType'
                },
                {
                    'name': 'createProductRelationTypes'
                },
                {
                    'name': 'updateProductRelationType'
                },
                {
                    'name': 'deleteProductRelationTypes'
                },
                {
                    'name': 'createProductRelation'
                },
                {
                    'name': 'deleteProductRelation'
                },
                {
                    'name': 'githubAuth'
                },
                {
                    'name': 'storeAdminAppToken'
                }
            ],
            'name': 'Mutation'
        },
        'product': {
            'description': None,
            'fields': [
                {
                    'name': 'version'
                },
                {
                    'name': 'node'
                },
                {
                    'name': 'webConfig'
                },
                {
                    'name': 'allProductTypes'
                },
                {
                    'name': 'productType'
                },
                {
                    'name': 'allProducts'
                },
                {
                    'name': 'allProductFilePaths'
                },
                {
                    'name': 'product'
                },
                {
                    'name': 'allProductRelationTypes'
                },
                {
                    'name': 'productRelationType'
                },
                {
                    'name': 'allProductRelations'
                },
                {
                    'name': 'productRelation'
                },
                {
                    'name': 'githubUser'
                },
                {
                    'name': 'oauthAppInfo'
                }
            ],
            'name': 'Query'
        }
    }
}

snapshots['test_disable_mutation[kwargs1] 1'] = {
    'data': {
        'Mutation': None,
        'product': {
            'description': None,
            'fields': [
                {
                    'name': 'version'
                },
                {
                    'name': 'node'
                },
                {
                    'name': 'webConfig'
                },
                {
                    'name': 'allProductTypes'
                },
                {
                    'name': 'productType'
                },
                {
                    'name': 'allProducts'
                },
                {
                    'name': 'allProductFilePaths'
                },
                {
                    'name': 'product'
                },
                {
                    'name': 'allProductRelationTypes'
                },
                {
                    'name': 'productRelationType'
                },
                {
                    'name': 'allProductRelations'
                },
                {
                    'name': 'productRelation'
                },
                {
                    'name': 'githubUser'
                },
                {
                    'name': 'oauthAppInfo'
                }
            ],
            'name': 'Query'
        }
    }
}

snapshots['test_disable_mutation[kwargs2] 1'] = {
    'data': {
        'Mutation': {
            'description': None,
            'fields': [
                {
                    'name': 'createProduct'
                },
                {
                    'name': 'updateProduct'
                },
                {
                    'name': 'deleteProduct'
                },
                {
                    'name': 'createProductFilePath'
                },
                {
                    'name': 'updateProductFilePath'
                },
                {
                    'name': 'deleteProductFilePath'
                },
                {
                    'name': 'createProductType'
                },
                {
                    'name': 'updateProductType'
                },
                {
                    'name': 'deleteProductType'
                },
                {
                    'name': 'createProductRelationTypes'
                },
                {
                    'name': 'updateProductRelationType'
                },
                {
                    'name': 'deleteProductRelationTypes'
                },
                {
                    'name': 'createProductRelation'
                },
                {
                    'name': 'deleteProductRelation'
                },
                {
                    'name': 'githubAuth'
                },
                {
                    'name': 'storeAdminAppToken'
                }
            ],
            'name': 'Mutation'
        },
        'product': {
            'description': None,
            'fields': [
                {
                    'name': 'version'
                },
                {
                    'name': 'node'
                },
                {
                    'name': 'webConfig'
                },
                {
                    'name': 'allProductTypes'
                },
                {
                    'name': 'productType'
                },
                {
                    'name': 'allProducts'
                },
                {
                    'name': 'allProductFilePaths'
                },
                {
                    'name': 'product'
                },
                {
                    'name': 'allProductRelationTypes'
                },
                {
                    'name': 'productRelationType'
                },
                {
                    'name': 'allProductRelations'
                },
                {
                    'name': 'productRelation'
                },
                {
                    'name': 'githubUser'
                },
                {
                    'name': 'oauthAppInfo'
                }
            ],
            'name': 'Query'
        }
    }
}
