from .product import (
    FRAGMENT_PRODUCT_SHALLOW,
    FRAGMENT_PRODUCT_CONNECTION_SHALLOW,
    FRAGMENT_PRODUCT_DEEP,
    FRAGMENT_PRODUCT_CONNECTION_DEEP,
    CREATE_PRODUCT,
    DELETE_PRODUCT,
    UPDATE_PRODUCT
)

from .product_relation_type import (
    FRAGMENT_PRODUCT_RELATION_TYPE,
    FRAGMENT_PRODUCT_RELATION_TYPE_CONNECTION,
    CREATE_PRODUCT_RELATION_TYPES,
    UPDATE_PRODUCT_RELATION_TYPE,
    DELETE_PRODUCT_RELATION_TYPES
    )

from .product_relation import (
    FRAGMENT_PRODUCT_RELATION,
    FRAGMENT_PRODUCT_RELATION_CONNECTION,
    CREATE_PRODUCT_RELATION,
    DELETE_PRODUCT_RELATION
    )

from .product_type import (
    FRAGMENT_PRODUCT_TYPE,
    FRAGMENT_PRODUCT_TYPE_CONNECTION,
    CREATE_PRODUCT_TYPE,
    UPDATE_PRODUCT_TYPE,
    DELETE_PRODUCT_TYPE
    )
